@@ -1,17 +1,18 @@
 """Base Class with helper methods common to all modules"""
 
-from functools import wraps
-from http import HTTPStatus
 import json
 import logging
+from functools import wraps
+from http import HTTPStatus
 
-from oauthlib.oauth2 import TokenExpiredError
 from oauth2_xfel_client.oauth2_client_backend import Oauth2ClientBackend
+from oauthlib.oauth2 import TokenExpiredError
 
 from ..common.config import CREATE, DELETE, UPDATE, GET, SET
 
+
 def replace_expired_token(func):
-    """Decorator to catch TokenExpiredError and make a session with a new token.
+    """Decorator to catch TokenExpiredError and make a session with a new token
 
     Doing it this way avoids a race condition where a token can expire between
     checking and using it. It also hopefully copes better if the client and
@@ -20,6 +21,7 @@ def replace_expired_token(func):
     TODO: Auto-refresh should be handled in requests_oauthlib, but
     oauth2_xfel_client v5.1.1 doesn't seem to use this.
     """
+
     @wraps(func)
     def inner(self, *args, **kwargs):
         try:
