@@ -5,13 +5,15 @@
 # APPLICATION MODULES
 #
 ##########################################################################
-DEVICE_TYPE = 'device_type'
-PHYSICAL_DEVICE = 'physical_device'
+DETECTOR = 'detector'
+DETECTOR_TYPE = 'detector_type'
+PHYSICAL_DETECTOR_UNIT = 'physical_detector_unit'
 PARAMETER = 'parameter'
 CONDITION = 'condition'
 CALIBRATION = 'calibration'
 CALIBRATION_CONSTANT = 'calibration_constant'
 CALIBRATION_CONSTANT_VERSION = 'calibration_constant_version'
+REPORT = 'report'
 
 ##########################################################################
 #
